#!/bin/bash
# PAM GEN's configuration

BASE_CONFIG_PREFIX="system"

# -----------------------------------------------------------
# Overwriting default configuration files
# -----------------------------------------------------------

# system-auth
cat <<'EOF'> /etc/pam.d/$BASE_CONFIG_PREFIX-auth
# Begin /etc/pam.d/system-auth
auth    required    pam_env.so
auth    required    pam_tally2.so onerr=fail deny=3 unlock_time=900 root_unlock_time=900 file=/var/log/tallylog
auth    required    pam_unix.so
auth    optional    pam_faildelay.so delay=4000000
EOF

# system-auth
cat <<'EOF'> /etc/pam.d/$BASE_CONFIG_PREFIX-account
# Begin /etc/pam.d/system-account
account    required    pam_tally2.so file=/var/log/tallylog
account    required    pam_unix.so
# End /etc/pam.d/system-account
EOF

# system-password
cat <<'EOF'> /etc/pam.d/$BASE_CONFIG_PREFIX-password
# Begin /etc/pam.d/system-password
password    requisite   pam_cracklib.so     minlen=8 minclass=4 difok=4 maxsequence=0 retry=3 enforce_for_root
password    requisite   pam_pwhistory.so    retry=3 remember=5 enforce_for_root
password    required    pam_unix.so         sha512 shadow use_authtok
# End /etc/pam.d/system-password
EOF

# system-session
cat <<'EOF'> /etc/pam.d/$BASE_CONFIG_PREFIX-session
# Begin /etc/pam.d/system-session
session   required    pam_unix.so
session   required    pam_limits.so
session   optional    pam_motd.so
session   optional    pam_lastlog.so showfailed
session   optional    pam_systemd.so
# End /etc/pam.d/system-session
EOF

# -----------------------------------------------------------
# Creating pam required files
# -----------------------------------------------------------

FILE_LIST="/etc/security/opasswd /var/log/tallylog"

for file in $FILE_LIST;do
    tmpfile=$(umask 0177 && mktemp "$file.XXXXXXXX")
    chown root:root $tmpfile
    ln -PT $tmpfile $file &>/dev/null
    rm $tmpfile
done

# -----------------------------------------------------------
# PAM configuration review for unauthorized args
# -----------------------------------------------------------

# Removing unauthorized args
PAM_MODULE_PARAMS="nullok magic_root"

for argument in $PAM_MODULE_PARAMS;do
    sed -i "s/$argument//g" /etc/pam.d/*
done

# -----------------------------------------------------------
# Services configuration review to make sure services are using PAM
# -----------------------------------------------------------

#sshd_config update to make it go through PAM for password authentication, restart service
if [ -f /etc/ssh/sshd_config ];then
    sed -i "s/UsePAM no/UsePAM yes/g" /etc/ssh/sshd_config
    sed -i "s/ChallengeResponseAuthentication no/ChallengeResponseAuthentication yes/g" /etc/ssh/sshd_config
    sed -i "s/PasswordAuthentication no/PasswordAuthentication yes/g" /etc/ssh/sshd_config
    sed -i "s/UseLogin yes/UseLogin no/g" /etc/ssh/sshd_config
    systemctl restart sshd
fi

# -----------------------------------------------------------
# Misc. perms check
# -----------------------------------------------------------

# Locking null passwords
USERS_WITH_BLANK_PW=$(passwd -S -a | grep " NP " | awk -F" " '{print $1}')
for user in $USERS_WITH_BLANK_PW;do
   echo "Attempting to lock user $user due to null password"
   passwd -l $user 2>&1
done

# Make sure we have 0600 permissions
PERM_ELEMENTS_LIST="/etc/security/ /etc/pam.d/ /usr/lib/security/"
for element in $PERM_ELEMENTS_LIST;do
    if [ -d $element ];then
        chown -R root:root $element
        chmod -R 0600 $element
    fi
done

